
.. include:: ../README.rst

.. toctree::
   :caption: Getting Started
   :hidden:
   :maxdepth: 1

   install
   configure
   howtostart

.. toctree::
   :caption: User Guide
   :maxdepth: 1
   :hidden:

   examples/index
   uses
   cli

.. toctree::
   :caption: Reference
   :maxdepth: 1
   :hidden:

   api
   accessors
   changes
   roadmap
   appendix

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
